package dpdknet

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// DisableRequest struct to disable DPDK network
// Computes will not be able to use it until it is enabled again.
type DisableRequest struct {
	// ID of DPDK network to disable
	// Required: true
	DPDKID uint64 `url:"dpdkId" json:"dpdkId" validate:"required"`
}

// Disable disables DPDK network by ID
func (d DPDKNet) Disable(ctx context.Context, req DisableRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/dpdknet/disable"

	res, err := d.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
